# Generated by Django 2.1 on 2020-04-24 06:32

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apiqa_storage', '0003_auto_20191017_1105'),
    ]

    operations = [
        migrations.AddField(
            model_name='attachment',
            name='tags',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=100), default=list, size=None, verbose_name='Тэги'),
        ),
    ]
