# Generated by Django 2.2.2 on 2019-10-17 11:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('apiqa_storage', '0002_auto_20190801_1236'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='attachment',
            options={'ordering': ('-created',), 'verbose_name': 'Вложение', 'verbose_name_plural': 'Вложения'},
        ),
    ]
