# Generated by Django 2.2.3 on 2019-08-01 12:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('apiqa_storage', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='name',
            field=models.CharField(max_length=255, verbose_name='Имя'),
        ),
    ]
